/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//#include <collate.h >
#include "DictIndexSearcher.h"
#include "MyUtils.h"

DictIndexSearcher::DictIndexSearcher()
{
	iIsOpen = EFalse;
}

DictIndexSearcher::~DictIndexSearcher()
{
	if (iIsOpen)
	{
		iFile.Close();
	}
	LOGGING_STOP;
}

TBool DictIndexSearcher::Open(const TDesC& aFileName)
{
	LOGGING_START(_L("DictLog"), _L("LogFileDictSearcher"));

	TInt err = iFile.Open(aFileName,
						  ETrue);
	if (err != KErrNone)
	{
		iIsOpen = EFalse;
		return EFalse;
	}

	iFileSize = iFile.GetSize();
	if (iFileSize <= 0)
	{
		iFile.Close();
		iIsOpen = EFalse;
		return EFalse;
	}

	iIsOpen = ETrue;
	return ETrue;
}


TInt DictIndexSearcher::FindWord(const TDesC& aSearchWord,
								 TInt& aPos)
{
	if (!iIsOpen || aSearchWord.Length() <= 0)
		return EFalse;

	//TCollationMethod collationMethod = *Mem::CollationMethodByIndex(0);
	//collationMethod.iFlags |= TCollationMethod::EFoldCase;
	TBuf<KSearchWordSizeMax> searchWord(aSearchWord);
	TBuf<KIndexEntryWordSizeMax> word;
	searchWord.LowerCase();

	DictIndexEntry indexEntry;
	TInt result = -1;
	TInt minPos = 0, maxPos = iFileSize;
	TBool found = EFalse;
	TInt pos = iFileSize / 2;
	TInt wordsFoundCount = 0;

	indexEntry.pos = indexEntry.length = 0;

	while(!found)
	{
		indexEntry = GetIndexEntryAt(pos);

		if (indexEntry.pos >= 0)
		{
			word.Copy(iLastEntryWord);
			word.LowerCase();
			result = searchWord.Compare(word);
			//result = aSearchWord.CompareC(iLastEntryWord, 3, &collationMethod);
			found = (result == 0);
		}
		else
		{
			aPos = 0;
			return 0;
		}

		if (!found)
		{
			if (indexEntry.pos < minPos ||
				(indexEntry.pos + indexEntry.length - 1) > maxPos)
			{
				aPos = indexEntry.pos;
				return 0;
			}

			if (result > 0)
			{
				minPos = indexEntry.pos + indexEntry.length;
				pos = pos + (maxPos - pos)/2;
				if (pos >= indexEntry.pos &&
					pos < (indexEntry.pos + indexEntry.length))
				{
					// Ended up in the same word
					pos = minPos;
				}
			}
			else
			{
				maxPos = indexEntry.pos - 1;
				pos = pos - ((pos - minPos)/2);
				if (pos >= indexEntry.pos &&
					pos < (indexEntry.pos + indexEntry.length))
				{
					// Ended up in the same word
					pos = maxPos;
				}
			}
			if (pos < minPos || pos > maxPos)
			{
				aPos = indexEntry.pos;
				return 0;
			}
		}
	}

	TInt mark = indexEntry.pos + indexEntry.length;

	// Move backwards
	while (found)
	{
		aPos = indexEntry.pos;
		wordsFoundCount++;
		pos = indexEntry.pos - 1;
		indexEntry = GetIndexEntryAt(pos);
		if (indexEntry.pos >= 0)
		{
			// <---
			TInt offset = (TInt) iLastEntryWord.Find(_L(" "));
			word.Copy(iLastEntryWord);
			word.LowerCase();
			if (offset > 3)
			{
				found = (searchWord.Compare(word.Mid(0, offset)) == 0);
				//found = (aSearchWord.CompareC(iLastEntryWord.Mid(0, offset),
				//							  3, &collationMethod) == 0);
			}
			else
			{
				found = (searchWord.Compare(word) == 0);
				//found = (aSearchWord.CompareC(iLastEntryWord,
				//							  3, &collationMethod) == 0);
			}
			// <---
		}
		else
		{
			break;
		}
	}

	// Move forwards
	found = ETrue;
	pos = mark;
	while (found)
	{
		indexEntry = GetIndexEntryAt(pos);
		if (indexEntry.pos >= 0)
		{
			// <---
			TInt offset = (TInt) iLastEntryWord.Find(_L(" "));
			word.Copy(iLastEntryWord);
			word.LowerCase();
			if (offset > 3)
			{
				found = (searchWord.Compare(word.Mid(0, offset)) == 0);
				//found = (aSearchWord.CompareC(iLastEntryWord.Mid(0, offset),
				//							  3, &collationMethod) == 0);
			}
			else
			{
				found = (searchWord.Compare(word) == 0);
				//found = (aSearchWord.CompareC(iLastEntryWord,
				//							  3, &collationMethod) == 0);
			}
			// <---
		}
		else
		{
			break;
		}
		if (found)
		{
			wordsFoundCount++;
			pos = indexEntry.pos + indexEntry.length;
		}
	}

	return wordsFoundCount;
}

DictIndexEntry DictIndexSearcher::GetIndexEntryAt(TInt aPos)
{
	TInt i, start, end;
	DictIndexEntry indexEntry;

	indexEntry.pos =-1;
	if (aPos >= iFileSize || aPos < 0)
		return indexEntry;

	if (iFile.ReadByte(aPos) == '\n' && aPos > 0)
		aPos--;

	for(i=aPos; i<iFileSize; i++)
	{
		if (iFile.ReadByte(i) == '\n')
			break;
	}
	end = i;
	for(i=aPos; i>=0; i--)
	{
		if (iFile.ReadByte(i) == '\n')
			break;
	}
	start = i+1;
	indexEntry.pos = start;
	indexEntry.length = end - start + 1;

	iLastEntryWord.Copy(_L(""));
	iLastOffset.Copy(_L(""));
	iLastLength.Copy(_L(""));

	if (indexEntry.length < KIndexEntryWordSizeMax)
	{
		TBuf8<KIndexEntryWordSizeMax> buf;

		iFile.Read(buf, start, indexEntry.length);

		TInt brk1 = 0, brk2 = 0;

		for(i=0; i<indexEntry.length; i++)
		{
			if (buf[i] == '\t')
			{
				if (brk1 == 0)
				{
					brk1 = i;
				}
				else if (brk2 == 0)
				{
					brk2 = i;
					break;
				}
			}
		}

		//					\t			\t		\n
		// 0	1	2	3	4	5	6	7	8	9
		// Word size = brk1, offset size = brk2 - brk1 - 2
		// 'length' size = length - brk2 - 1
		if (brk1 > 0 && brk2 > 0 && brk1 < KIndexEntryWordSizeMax &&
			(brk2 - brk1 - 1) < 10 && (indexEntry.length - brk2 - 2) < 10)
		{
			MyUtils::ConvertTDes8ToTDes16(buf.Mid(0, brk1), iLastEntryWord);
			iLastOffset.Copy(buf.Mid(brk1 + 1, brk2 - brk1 - 1));
			iLastLength.Copy(buf.Mid(brk2 + 1, indexEntry.length - brk2 - 2));
		}

		TInt length = iLastLength.Length();
		if (length > 1 && iLastLength[length - 1] == '\r')
		{
			iLastLength = iLastLength.Left(length - 1);
		}
	}

	return indexEntry;
}

TBool DictIndexSearcher::GetEntryAt(TInt& aPos,
									TDes& aWord,
									TDes8& aDzFileOffset,
									TDes8& aDzFileLength)
{
	if (aPos >= iFileSize || aPos < 0)
		return EFalse;

	DictIndexEntry indexEntry = GetIndexEntryAt(aPos);
	aPos += indexEntry.length;

	aWord = iLastEntryWord;
	aDzFileOffset = iLastOffset;
	aDzFileLength = iLastLength;

	LOG_WRITE(aWord);
	LOG_WRITE(aDzFileOffset);
	LOG_WRITE(aDzFileLength);

	return ETrue;
}