/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <eikenv.h>
#include "FileRandomReader.h"

FileRandomReader::FileRandomReader()
{
	iIsOpen = EFalse;
	iBufferStart = -1;
	iBufferEnd = -1;
}


FileRandomReader::~FileRandomReader()
{
	if (iIsOpen)
		iFile.Close();
}

TInt FileRandomReader::Open(const TDesC& aFileName,
							TBool aReadBufferInBothDirections)
{
	if (iIsOpen)
		return EFalse;

	iReadBufferInBothDirections = aReadBufferInBothDirections;

	RFs	iFileSession;
	iFileSession = CEikonEnv::Static()->FsSession();
	TInt err = iFile.Open(iFileSession,
						  aFileName,
						  EFileRead);
	if (err == KErrNone)
	{
		err = iFile.Size(iLength);
		if (err == KErrNone)
		{
			iIsOpen = ETrue;
			return KErrNone;
		}
	}
	return err;
}

void FileRandomReader::Close()
{
	iFile.Close();
	iIsOpen = EFalse;
}

TInt FileRandomReader::GetSize()
{
	TInt size;

	if (iIsOpen)
	{
		if (iFile.Size(size) == KErrNone)
			return size;
	}
	return 0;
}

TBool FileRandomReader::Read(TDes8& aDes, TInt aPos, TInt aLength)
{
	if (aLength > KBufferSize)
	{
		if (iFile.Seek(ESeekStart, aPos) != KErrNone)
		{
			return EFalse;
		}
		if (iFile.Read(aDes, aLength) != KErrNone)
		{
			return EFalse;
		}
		return ETrue;
	}

	if (!UpdateBuffer(aPos, aLength))
		return EFalse;

	aDes.Copy(iBuffer.Ptr() + (aPos - iBufferStart), aLength);

	return ETrue;
}

TUint8 FileRandomReader::ReadByte(TInt aPos)
{
	if (!UpdateBuffer(aPos, 1))
		return 0xFF;

	return iBuffer[aPos - iBufferStart];
}

TUint16 FileRandomReader::ReadWord(TInt aPos)
{
	if (!UpdateBuffer(aPos, 2))
		return 0xFFFF;

	return *((TUint16 *) &iBuffer[aPos - iBufferStart]);
}

TInt FileRandomReader::ReadInt(TInt aPos)
{
	if (!UpdateBuffer(aPos, sizeof(TInt)))
		return -1;

	return *((TInt *) &iBuffer[aPos - iBufferStart]);
}

TBool FileRandomReader::UpdateBuffer(TInt aPos, TInt aLength)
{
	TInt pos = aPos;

	if (pos < 0 || aLength < 0 || aLength > KBufferSize ||
	    (pos + aLength) > iLength || !iIsOpen)
	{
		return EFalse;
	}

	if (pos >= iBufferStart &&
		(pos + aLength - 1) <= iBufferEnd)
	{
		return ETrue;
	}

	if (iReadBufferInBothDirections && (aLength < KBufferSize/2))
	{
		pos = pos - KBufferSize/2;
		if (pos < 0)
			pos = 0;
	}

	if (iFile.Seek(ESeekStart, pos) != KErrNone)
	{
		return EFalse;
	}

	TInt length;
	if (pos + KBufferSize <= iLength)
	{
		length = KBufferSize;
	}
	else
	{
		length = iLength - pos;
	}

	if (iFile.Read(iBuffer, length) != KErrNone)
	{
		iBufferStart = -1;
		iBufferEnd = -1;
		return EFalse;
	}

	iBufferStart = pos;
	iBufferEnd = pos + length - 1;
	return ETrue;
}