/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __FILE_RANDOM_READER_TEST_H__
#define __FILE_RANDOM_READER_TEST_H__

#include "FileRandomReader.h"
#include <flogger.h>

/** Class for testing the implementation of FileRandomReader. Requires
	FileRandomReaderTestFile1 and FileRandomReaderTestFile2 to be placed
	in the application's installation directory.*/
class CFileRandomReaderTest : public CBase
{
public:
	/** Constructor. */
	CFileRandomReaderTest();

	/** Destructor. */
	~CFileRandomReaderTest();

	/** Constructs a CFileRandomReaderTest object.
		@result A pointer to the created instance of CFileRandomReaderTest.
	*/
	static CFileRandomReaderTest *NewL();

	/** Performs the second phase construction of a CFileRandomReaderTest object.
	*/
	void ConstructL();

	/** Starts the testing.
		@result True if the operation was successful.*/
	TBool StartTesting();

	/** Performs byte reading tests.
		@result The outcome of the test.
	*/
	TBool ReadByteTest();

	/** Performs word reading tests.
		@result The outcome of the test.
	*/
	TBool ReadWordTest();

	/** Performs integer reading tests.
		@result The outcome of the test.
	*/
	TBool ReadIntTest();

	/** Performs strings reading tests.
		@result The outcome of the test.
	*/
	TBool ReadStringTest();

	/** Performs long strings (longer than the size of the internal buffer)
		reading tests.
		@result The outcome of the test.
	*/
	TBool ReadLongStringTest();

private:
	/** File logger. */
	RFileLogger iLog;

	/** FileRandomReader object used for testing. */
	FileRandomReader *aFileReader1;

	/** FileRandomReader object used for testing. */
	FileRandomReader *aFileReader2;

	TBool iFile1Open;
	TBool iFile2Open;
};

#endif //__FILE_RANDOM_READER_TEST_H__