/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.

	This code has been adapted from dictd-1.9.15
	(ftp://ftp.dict.org/pub/dict/dictd-1.9.15.tar.gz)
	Copyright Rickard E. Faith (faith@dict.org)

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/** @file base64.h
	This code has been taken from
	<A HREF="ftp://ftp.dict.org/pub/dict/dictd-1.9.15.tar.gz">dictd-1.9.15</A>.
	Copyright Rickard E. Faith (faith@dict.org)
*/

#ifndef _BASE64_H_
#define _BASE64_H_

#include <e32std.h>
#include <e32def.h>

#define XX 100

/** Class for converting numbers encoded in a base64 system to integers.
This base64 format is used by dict index files to store the length and
offset of each entry. The code has been adapted from dictd-1.9.15.
*/
class Base64
{
private:
	/**Look-up table for converting a single character to a base64 value.*/
	static const TUint8 b64_index[256];

public:
	/** Converts a string representing a base64 number to an integer.
		@param aVal A reference to the string to convert.
		@result The integer that the string represents.
	*/
	static TInt Decode(const TDesC8 &aVal)
	{
		TInt v = 0;
		TInt i;
		TInt offset = 0;
		TInt len = aVal.Length();

		for (i = len - 1; i >= 0; i--)
		{
			int tmp = b64_index[ (aVal.Ptr())[i] ];

			if (tmp == XX)
			{
				//Illegal character in base64 value
				return(0);
			}

			v |= tmp << offset;
			offset += 6;
		}

		return v;
	}
};

#endif //_BASE64_H_