/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __DICT_DOCUMENT_H__
#define __DICT_DOCUMENT_H__

#include <akndoc.h>

class CDictAppUi;
class CEikApplication;


/**
  An instance of class CDictDocument is the Document part of the AVKON
  application framework for the Dict application. Derived from CAknDocument.
  */
class CDictDocument : public CAknDocument
	{
public:

/**
  Constructs a CDictDocument for the AVKON application aApp
  using two phase construction. Returns a pointer to the created object.
  @param aApp Aapplication creating this document.
  @result A pointer to the created instance of CDictDocument.
  */
	static CDictDocument* NewL(CEikApplication& aApp);

/**
  Constructs a CDictDocument for the AVKON application aApp
  using two phase construction. Returns a pointer to the created object.
  @param aApp Application creating this document.
  @result A pointer to the created instance of CDictDocument.
  */
	static CDictDocument* NewLC(CEikApplication& aApp);

/**
  Destructor.
  */
	~CDictDocument();

public: // from CAknDocument
/**
  Creates a CDictAppUi object and return a pointer to it.
  (from CAknDocument)
  @result A pointer to the created instance of the AppUi created.
  */
	CEikAppUi* CreateAppUiL();

private:

/**
   Perform the second phase construction of a CDictDocument object.
  */
	void ConstructL();

/**
  Perform thes first phase of two phase construction.
  @param aApp Application creating this document.
  */
	CDictDocument(CEikApplication& aApp);

	};

#endif // __DICT_DOCUMENT_H__
