/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __DICT_MEANING_CONTAINER_H__
#define __DICT_MEANING_CONTAINER_H__

#include <aknview.h>

class CEikRichTextEditor;
class CDictMeaningView;

/**
  An instance of CDictMeaningContainer contains the view drawn to
  the screen for CDictMeaningView.
*/
class CDictMeaningContainer : public CCoeControl
	{
public:
/**
  Constructor.
*/
	CDictMeaningContainer();


/**
  Destructor.
*/
	~CDictMeaningContainer();

/**
  Creates a CDictMeaningContainer object, which will draw itself to aRect.
  @param aRect The rectangle this view will be drawn to.
  @result A pointer to the created instance of CDictMeaningContainer.
*/
	static CDictMeaningContainer* NewL(const TRect& aRect);

/**
  Creates a CDictMeaningContainer object, which will draw itself to aRect.
  @param aRect The rectangle this view will be drawn to.
  @result A pointer to the created instance of CDictMeaningContainer.
*/
	static CDictMeaningContainer* NewLC(const TRect& aRect);

/**
  Performs the second phase construction of a CDictMeaningContainer object.
  @param aRect Frame rectangle for container.
*/
	void ConstructL(const TRect& aRect);

public: // from CoeControl
/**
  Returns the number of controls contained in this compound control.
  (from CoeControl)
  @result The number of controls.
*/
	TInt CountComponentControls() const;

/**
  Returns a pointer the specified component. (from CoeControl)
  @param aIndex Specification for component pointer.
  @return Pointer to component control.
*/
	CCoeControl* ComponentControl(TInt aIndex) const;

/**
  Draws this CDictMeaningContainer to the screen. (from CoeControl)
  @param aRect The rectangle of this view that needs updating.
*/
	void Draw(const TRect& aRect) const;

/**
  Handles a 'key event'. (from CoeControl)
  @param aCode The keycode.
  */
	void KeyEventL(TInt aCode);

/**
  Offers the key event to the rich-text control. (from CoeControl)
  @param aKeyEvent The key that caused the event.
  @param aType The type of event that occured.
  */
	TKeyResponse OfferKeyEventL(const TKeyEvent& aKeyEvent, TEventCode aType);

public:
/**
  Sets the meaning text.
  @param aText A pointer to the meaning text.
  */
	void SetMeaningText(const TDesC* aText) {iText = aText;};
	
#ifdef __SERIES60_30__	
	void  HandleResourceChange(TInt aType);
#endif

private:
/**
  Adds a string to the rich-text control.
  @param aDes The string to be added.
  @param aBold If true the text is rendered in bold.
  @param aItalics If true the text is rendered in italics.
  */
	void AddTextL(const TDesC& aDes,
				  TBool aBold = EFalse,
				  TBool aItalics = EFalse);

/**
  Updates the rich-text control.
  */
	void UpdateMeaningL();

private:
	/** A pointer to the meaning text. */
	const TDesC *iText;

	/** Object for use as meaning window.*/
	CEikRichTextEditor* iMeaningWindow;
	};

#endif // __DICT_MEANING_CONTAINER_H__
