/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __DICT_SEARCH_VIEW_H__
#define __DICT_SEARCH_VIEW_H__

#include <aknview.h>

#define KMaxSearchWordSize		20
#define KMaxDictionaryNameSize	20

class CDictSearchContainer;

/**
  An instance of the Search View object for the Dict application.
  Search View displays the name of the active dictionary and a text-box for
  entering the word to search.
*/
class CDictSearchView: public CAknView
	{
public:

/**
  Creates a CDictSearchView object.
  @result A pointer to the created instance of CDictSearchView.
*/
	static CDictSearchView* NewL();

/**
  Creates a CDictSearchView object.
  @result A pointer to the created instance of CDictSearchView.
*/
	static CDictSearchView* NewLC();

/**
  Destructor.
*/
	~CDictSearchView();

public: // from CAknView

/**
  Identity of this view to the system. (from CAknView)
  @result The ID of view.
*/
	TUid Id() const;

/**
  Handles commands. (from CAknView)
  @param aCommand Command to be handled.
*/
	void HandleCommandL(TInt aCommand);

/**
  Creates the Container class object. (from CAknView)
  @param aPrevViewId The id of the previous view.
  @param aCustomMessageId Message identifier.
  @param aCustomMessage Custom message provided when the view is changed.
*/
	void DoActivateL(const TVwsViewId& aPrevViewId,
				  TUid aCustomMessageId,
				  const TDesC8& aCustomMessage);

/**
  Removes the container class instance from the App UI's stack and deletes
  the instance. (from CAknView)
  */
	void DoDeactivate();

private:

/**
  Performs the first phase of two phase construction.
*/
	CDictSearchView();

/**
  Performs the second phase construction of a CDictSearchView object.
*/
	void ConstructL();

public:
/**
  Sets the name of the active dictionary.
  @param aName The name of the new dictionary.
*/
	void SetDictionaryName(const TDesC& aName);

private:
	/** Stores the word to search for. */
	TBuf<KMaxSearchWordSize+1> iWordToSearch;

	/** Stores the name of the active dictionary. */
	TBuf<KMaxDictionaryNameSize> iDictionaryName;

	/** Container for this view. */
	CDictSearchContainer* iContainer;

	/** Identifier for this view. */
	TUid iIdentifier;
	};


#endif // __DICT_SEARCH_VIEW_H__
