/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <eikrted.h>
#include <barsread.h>
#include <txtrich.h>
#include <txtfrmat.h>
#include <gdi.h>
#include <S60Dict.rsg>
#if defined(__SYMBIAN_7__) || defined(__SERIES60_30__)	
#include <aknsskininstance.h> 
#include <aknscontrolcontext.h>
#include <aknsdrawutils.h> 
#include <aknutils.h> 
#endif

#include "Dict.pan"
#include "DictMeaningContainer.h"

const TPoint KMeaningWindowPosition  = TPoint(5, 5);

CDictMeaningContainer::CDictMeaningContainer()
{
	iMeaningWindow = NULL;
}


CDictMeaningContainer::~CDictMeaningContainer()
{
	delete iMeaningWindow;
	iMeaningWindow = NULL;
}


CDictMeaningContainer* CDictMeaningContainer::NewL(const TRect& aRect)
	{
	CDictMeaningContainer* self = CDictMeaningContainer::NewLC(aRect);
	CleanupStack::Pop(self);
	return self;
	}

CDictMeaningContainer* CDictMeaningContainer::NewLC(const TRect& aRect)
	{
	CDictMeaningContainer* self = new (ELeave) CDictMeaningContainer;
	CleanupStack::PushL(self);
	self->ConstructL(aRect);
	return self;
	}

void CDictMeaningContainer::ConstructL(const TRect& aRect)
	{
	
	
	//const TSize  KMeaningWindowSize      = TSize(165, 140);
	TSize  iMeaningWindowSize      = aRect.Size();
	iMeaningWindowSize.iWidth -=KMeaningWindowPosition.iX;
	iMeaningWindowSize.iHeight -=KMeaningWindowPosition.iY;

	CreateWindowL();

	TResourceReader reader;
	iCoeEnv->CreateResourceReaderLC(reader, R_MEANING_WINDOW_RTEXTED);
	iMeaningWindow = new (ELeave) CEikRichTextEditor();

	iMeaningWindow->SetContainerWindowL(*this);
	iMeaningWindow->ConstructFromResourceL(reader);
	CleanupStack::PopAndDestroy();
	iMeaningWindow->SetFocus(ETrue);
	iMeaningWindow->SetExtent(KMeaningWindowPosition, iMeaningWindowSize);
	//iMeaningWindow->SetBorder(TGulBorder::ESingleBlack);

	SetRect(aRect);
	ActivateL();

	if (iText != NULL)
	{
		AddTextL(*iText);
		UpdateMeaningL();
	}

	}

TInt CDictMeaningContainer::CountComponentControls() const
	{
	return 1;
	}

void CDictMeaningContainer::Draw(const TRect& aRect) const
	{
	CWindowGc& gc = SystemGc();

	gc.SetPenStyle( CGraphicsContext::ENullPen );
	gc.SetBrushColor( KRgbWhite );
	gc.SetBrushStyle( CGraphicsContext::ESolidBrush );
	gc.DrawRect( aRect );
	}

CCoeControl* CDictMeaningContainer::ComponentControl(TInt aIndex) const
	{
	switch(aIndex)
	    {
	        case 0:
				return iMeaningWindow;
	        default:
	            Panic(EDictMeaningContainer);
	            return 0;
	    }
	}

TKeyResponse CDictMeaningContainer::OfferKeyEventL(const TKeyEvent& aKeyEvent,
												  TEventCode aType)
	{
	TKeyResponse keyResponce(EKeyWasNotConsumed);

	keyResponce = iMeaningWindow->OfferKeyEventL(aKeyEvent, aType);

	return keyResponce;
	}

void CDictMeaningContainer::KeyEventL(TInt aCode)
	{
	// Add this 'keypress' to the main output window
	TKeyEvent event;
	event.iCode = aCode;
	event.iScanCode = aCode;
	iMeaningWindow->SetFocus(ETrue);
	iMeaningWindow->OfferKeyEventL(event, EEventKey);
	}

void CDictMeaningContainer::AddTextL(const TDesC& aDes,
									 TBool aBold,
									 TBool aItalics)
	{
	// Display these characters in the meaning window, in the specified style
	CRichText *richText = iMeaningWindow->RichText();
	TInt aPos = richText->DocumentLength();

	richText->InsertL(aPos, aDes);

	TCharFormat charFormat;
	TCharFormatMask charFormatMask;

	TFontStyle fontStyle(aItalics ? EPostureItalic : EPostureUpright,
						 aBold ? EStrokeWeightBold : EStrokeWeightNormal,
						 EPrintPosNormal);

	charFormatMask.SetAttrib(EAttColor);
	charFormatMask.SetAttrib(EAttFontPosture);		// Italics
	charFormatMask.SetAttrib(EAttFontStrokeWeight);	// Bold

	charFormat.iFontPresentation.iTextColor = KRgbDarkGreen;
	charFormat.iFontSpec.iFontStyle = fontStyle;

	richText->ApplyCharFormatL(charFormat, charFormatMask, aPos,
							   aDes.Length());
	}

void CDictMeaningContainer::UpdateMeaningL()
{
	iMeaningWindow->HandleTextChangedL();
	iMeaningWindow->SetCursorPosL(0, EFalse);
}

//void CDictMeaningContainer::UpdateFontAttribute(TUint aFontStyle, TInt aAttribute)
//	{
//	// Ensure an individual attribute is on or off as requested
//	if ((aFontStyle & aAttribute) != (iFontStyle & aAttribute))
//		{
//		// Note: This function 'toggles' styles based on the bits set in
//		//supplied mask i.e. supplying the same bit twice toggles that style
//		//on then off again
//		TRAPD(error, iMeaningWindow->BoldItalicUnderlineEventL(aAttribute));
//		if(error != KErrNone)
//			{
//			Panic (EDictMeaningContainer);
//			}
//		iFontStyle ^= aAttribute;
//		}
//	}


#ifdef __SERIES60_30__
void  CDictMeaningContainer::HandleResourceChange(TInt aType)
{
	CCoeControl::HandleResourceChange(aType);
    if  ( aType == KEikDynamicLayoutVariantSwitch ) {
    	TRect rect;
    	AknLayoutUtils::LayoutMetricsRect(AknLayoutUtils::EMainPane, rect);
		SetRect(rect);
		TSize  iMeaningWindowSize      = rect.Size();
		iMeaningWindowSize.iWidth -=KMeaningWindowPosition.iX;
		iMeaningWindowSize.iHeight -=KMeaningWindowPosition.iY;
		iMeaningWindow->SetExtent(KMeaningWindowPosition, iMeaningWindowSize);
    }
}
#endif
