/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <aknviewappui.h>
#include <aknconsts.h>
#include <S60Dict.rsg>

#include "DictAppUi.h"
#include "DictResultsListView.h"
#include "DictResultsListContainer.h"
#include "Dict.hrh"

CDictResultsListView* CDictResultsListView::NewL()
	{
	CDictResultsListView* self = CDictResultsListView::NewLC();
	CleanupStack::Pop(self);
	return self;
	}

CDictResultsListView* CDictResultsListView::NewLC()
	{
	CDictResultsListView* self = new (ELeave) CDictResultsListView();
	CleanupStack::PushL(self);
	self->ConstructL();
	return self;
	}

CDictResultsListView::CDictResultsListView()
	{
	// No implementation required
	}

CDictResultsListView::~CDictResultsListView()
	{
	// No implementation required
	}

void CDictResultsListView::ConstructL()
	{
	BaseConstructL(R_DICT_RESULTS_LIST_VIEW);
	}


TUid CDictResultsListView::Id() const
	{
	return TUid::Uid(EDictResultsListViewId);
	}

void CDictResultsListView::DoActivateL(const TVwsViewId& /*aPrevViewId*/,
									  TUid /*aCustomMessageId*/,
									  const TDesC8& /*aCustomMessage*/)
	{
	ASSERT(!(iContainer));
	iContainer = new(ELeave) CDictResultsListContainer;
	iContainer->SetMopParent(this);
	iContainer->SetParentView(this);
	iContainer->SetHeadwordList(iHeadwordList);
	iContainer->ConstructL(ClientRect());
	iContainer->SetCurrentSelection(iCurrentSelection);
	AppUi()->AddToStackL(*this, iContainer);

	}

void CDictResultsListView::DoDeactivate()
	{
	if (iContainer)
		{
		AppUi()->RemoveFromStack(iContainer);
		delete iContainer;
		iContainer = NULL;
		}
	}

void CDictResultsListView::SetHeadwordList(CDesCArrayFlat* aList)
{
	iHeadwordList = aList;
	iCurrentSelection = -1;
}

void CDictResultsListView::ShowItemL(TInt aIndex)
{
	CDictAppUi *appUi = STATIC_CAST(CDictAppUi*, AppUi());
	iCurrentSelection = aIndex;
	appUi->ShowItemL(aIndex);
}

void CDictResultsListView::HandleCommandL(TInt aCommand)
	{
	if (aCommand == EDictResultsListViewBackCmd ||
		aCommand == EAknSoftkeyBack)
		{
		AppUi()->ActivateLocalViewL(TUid::Uid(EDictSearchViewId));
		}
	else
		{
		AppUi()->HandleCommandL(aCommand);
		}
	}
