/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <eiklabel.h>
#include <eikedwin.h>
#include <barsread.h>
#include <S60Dict.rsg>


#include "Dict.pan"
#include "DictSearchContainer.h"
#include "DictSearchView.h"
#if defined(__SYMBIAN_7__) || defined(__SERIES60_30__)	
#include <aknsskininstance.h> 
#include <aknscontrolcontext.h>
#include <aknsdrawutils.h> 
#include <aknutils.h> 
#endif

CDictSearchContainer::CDictSearchContainer()
{
	iLabelWindow = NULL;
	iSearchTextEditor = NULL;
	iWordToSearch = NULL;
	iDictionaryName = NULL;
	const TPoint KSearchTextEditorPosition  = TPoint(9, 31);
	const TSize  KSearchTextEditorSize	  = TSize(152, 22);
	iSearchTextEditorPosition = KSearchTextEditorPosition;
	iSearchTextEditorSize = KSearchTextEditorSize;
}

CDictSearchContainer::~CDictSearchContainer()
{
	delete iLabelWindow;
	iLabelWindow = NULL;

	delete iSearchTextEditor;
	iSearchTextEditor = NULL;
}


CDictSearchContainer* CDictSearchContainer::NewL(const TRect& aRect)
	{
	CDictSearchContainer* self = CDictSearchContainer::NewLC(aRect);
	CleanupStack::Pop(self);
	return self;
	}

CDictSearchContainer* CDictSearchContainer::NewLC(const TRect& aRect)
	{
	CDictSearchContainer* self = new (ELeave) CDictSearchContainer;
	CleanupStack::PushL(self);
	self->ConstructL(aRect);
	return self;
	}

void CDictSearchContainer::ConstructL(const TRect& aRect)
	{
	const TPoint KLabelPosition  = TPoint(10, 10);
	
	const TPoint KSearchTextEditorPosition  = TPoint(10, 32);
	const TSize  KSearchTextEditorSize	  = TSize(150, 20);

	CreateWindowL();

	iLabelWindow = new (ELeave) CEikLabel;
	iLabelWindow->SetContainerWindowL(*this);
	if (iDictionaryName)
		iLabelWindow->SetTextL(*iDictionaryName);
	else
		iLabelWindow->SetTextL(_L(""));
		
	TSize  LabelSize	  = aRect.Size();
	
	LabelSize.iWidth -= 20;
	LabelSize.iHeight = 15*aRect.Height()/100;
		
	iLabelWindow->SetExtent(KLabelPosition, LabelSize);

	//TResourceReader reader;
	iSearchTextEditor = new(ELeave) CEikEdwin;
	iSearchTextEditor->SetContainerWindowL(*this);
	iSearchTextEditor->ConstructL(EAknEditorFlagDefault,
								150,				// Width in pixels
								KMaxSearchWordSize, // Maximum number of characters
								1);					// Number of lines
	//iCoeEnv->CreateResourceReaderLC(reader, R_DICT_SEARCH_WORD_EDIT);
	//iSearchTextEditor->ConstructFromResourceL(reader);
	//CleanupStack::PopAndDestroy();
	
	iSearchTextEditorSize.iWidth = 8*aRect.Width()/10;
	iSearchTextEditorSize.iHeight = 20*aRect.Height()/100;
	iSearchTextEditorPosition.iX = aRect.Width()/10;
	iSearchTextEditorPosition.iY = 3*aRect.Height()/10;
	iSearchTextEditor->SetExtent(iSearchTextEditorPosition, iSearchTextEditorSize);
	iSearchTextEditorPosition.iX--;
	iSearchTextEditorPosition.iY--; 
	iSearchTextEditorSize.iWidth+=2;
	iSearchTextEditorSize.iHeight+=2;
	
	

	SetRect(aRect);
	ActivateL();

	if (iWordToSearch)
	{
		iSearchTextEditor->SetTextL(iWordToSearch);
		iSearchTextEditor->ClearSelectionL();
	}
	iSearchTextEditor->SetFocus(ETrue);
	}

void CDictSearchContainer::GetWordToSearch(TDes& aDes)
{
	iSearchTextEditor->GetText(aDes);
}

TInt CDictSearchContainer::CountComponentControls() const
	{
	return 2;
	}

void CDictSearchContainer::Draw(const TRect& aRect) const
	{
	CWindowGc& gc = SystemGc();
	gc.SetPenStyle( CGraphicsContext::ENullPen );
	gc.SetBrushColor( KRgbWhite );
	gc.SetBrushStyle( CGraphicsContext::ESolidBrush );
	gc.DrawRect( aRect );
	gc.SetPenStyle( CGraphicsContext::ESolidPen );
	gc.DrawRect(TRect(iSearchTextEditorPosition,
					  iSearchTextEditorSize));
	}

CCoeControl* CDictSearchContainer::ComponentControl(TInt aIndex) const
	{
	switch(aIndex)
		{
			case 0:
				return iLabelWindow;
			case 1:
				return iSearchTextEditor;
			default:
				Panic(EDictSearchContainer);
				return 0;
		}
	}

TKeyResponse CDictSearchContainer::OfferKeyEventL(const TKeyEvent& aKeyEvent,
												  TEventCode aType)
	{
	TKeyResponse keyResponce(EKeyWasNotConsumed);

	keyResponce = iSearchTextEditor->OfferKeyEventL(aKeyEvent, aType);

	return keyResponce;

	}

void CDictSearchContainer::SetDictionaryName(TDesC* aName)
{
	iDictionaryName = aName;
	if (iLabelWindow)
	{
		if (iDictionaryName)
			iLabelWindow->SetTextL(*iDictionaryName);
		else
			iLabelWindow->SetTextL(_L(""));
	}
}

#ifdef __SERIES60_30__
void CDictSearchContainer::HandleResourceChange(TInt aType)
{
	CCoeControl::HandleResourceChange(aType);
    if  ( aType == KEikDynamicLayoutVariantSwitch ) {
    	TRect rect;
    	AknLayoutUtils::LayoutMetricsRect(AknLayoutUtils::EMainPane, rect);
		SetRect(rect);
		iSearchTextEditorSize.iWidth = 8*rect.Width()/10;
		iSearchTextEditorSize.iHeight = 20*rect.Height()/100;
		iSearchTextEditorPosition.iX = rect.Width()/10;
		iSearchTextEditorPosition.iY = 3*rect.Height()/10;
		iSearchTextEditor->SetExtent(iSearchTextEditorPosition, iSearchTextEditorSize);
		iSearchTextEditorPosition.iX--;
		iSearchTextEditorPosition.iY--; 
		iSearchTextEditorSize.iWidth+=2;
		iSearchTextEditorSize.iHeight+=2;
    }
}
#endif
