/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <aknviewappui.h>
#include <aknconsts.h>
#include <S60Dict.rsg>

#include "DictAppUi.h"
#include "DictSearchView.h"
#include "DictSearchContainer.h"
#include "Dict.hrh"

CDictSearchView* CDictSearchView::NewL()
	{
	CDictSearchView* self = CDictSearchView::NewLC();
	CleanupStack::Pop(self);
	return self;
	}

CDictSearchView* CDictSearchView::NewLC()
	{
	CDictSearchView* self = new (ELeave) CDictSearchView();
	CleanupStack::PushL(self);
	self->ConstructL();
	return self;
	}

CDictSearchView::CDictSearchView()
	{
	// No implementation required
	}

CDictSearchView::~CDictSearchView()
	{
	// No implementation required
	}

void CDictSearchView::ConstructL()
	{
	BaseConstructL(R_DICT_SEARCH_VIEW);
	}


TUid CDictSearchView::Id() const
	{
	return TUid::Uid(EDictSearchViewId);
	}

void CDictSearchView::DoActivateL(const TVwsViewId& /*aPrevViewId*/,
	                                TUid /*aCustomMessageId*/,
	                                const TDesC8& /*aCustomMessage*/)
	{
	ASSERT(!(iContainer));
	iContainer = new(ELeave) CDictSearchContainer;
	iContainer->SetMopParent(this);
	iContainer->SetWordToSearch(&iWordToSearch);
	iContainer->SetDictionaryName(&iDictionaryName);
	iContainer->ConstructL(ClientRect());
	AppUi()->AddToStackL(*this, iContainer);
	}

void CDictSearchView::DoDeactivate()
	{
	if (iContainer)
	    {
	    AppUi()->RemoveFromStack(iContainer);
	    delete iContainer;
	    iContainer = NULL;
	    }
	}

void CDictSearchView::HandleCommandL(TInt aCommand)
	{
	if (aCommand == EDictSearchCmd ||
		aCommand == EAknSoftkeyDone)
	    {
			CDictAppUi *appUi = STATIC_CAST(CDictAppUi*, AppUi());

			iContainer->GetWordToSearch(iWordToSearch);

			if (iWordToSearch.Length() > 0)
				appUi->SearchWordL(iWordToSearch);
	    }
	else
	    {
	    AppUi()->HandleCommandL(aCommand);
	    }
	}

void CDictSearchView::SetDictionaryName(const TDesC &aName)
{
	iDictionaryName.Copy(aName.Left(KMaxDictionaryNameSize));
	if (iContainer)
	{
		iContainer->SetDictionaryName(&iDictionaryName);
	}
}
